@@ -1114,3 +1114,35 @@ class BlogExtension(Extension):
             parser.stream.skip_if('comma')
 
         return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
+
+
+class TopPromoExtension(Extension):
+    tags = set(['top_promo'])
+
+    def __init__(self, environment):
+        super(TopPromoExtension, self).__init__(environment)
+
+    def _render(self, caller=None):
+        casinos, found = Page.provider_by_context(
+            country=current_user.country_full,
+            is_searchable=True,
+            is_redirect=False,
+            provider_tags='TopPromo',
+            _locale=g.language,
+            _source = [
+                "title", 
+                "alias", 
+                "path",
+            ], 
+            _count=3
+        )    
+        t = current_app.jinja_env.get_template('_exp-promo.html')
+        s = t.render(casinos=casinos, found=found)
+        return s
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+
+        body = ''
+        args = []
+        return CallBlock(self.call_method("_render", args), [], [], body).set_lineno(lineno)
