@@ -263,7 +263,8 @@ class ElasticEntity(BaseEntity):
     @classmethod
     def put(cls, _id, doc, _refresh=True, _signal=True):
         obj = cls(doc, _id)
-        cls.on_pre_put.send(obj)
+        if _signal:
+            cls.on_pre_put.send(obj)
         resp = current_app.es.update(index=cls._table(), id=obj._id, body={'doc': obj.to_dict(), 'doc_as_upsert': True}, refresh=_refresh, retry_on_conflict=3)
         logger.debug(u'PUT: {0}'.format(resp))
         if _signal:
@@ -701,9 +702,11 @@ class Page(ElasticEntity):
                 'slogo_w150', 
                 'logo_w250', 
                 'cover_w300', 
-                'cover_w300_h200', 
+                'cover_w300_h200',
+                'cover_w600',
+                'cover_w1200', 
                 'content_w700',
-                'meta_w1200_h630'
+                'meta_w1200_h630',
             ],
             'media_rename': ['none', 'entity', 'hash'],
             'promo_types': ['Welcome Bonus', '1st Deposit Bonus', '2nd Deposit Bonus', '3rd Deposit Bonus', '4th Deposit Bonus', 'No Deposit', 'Cashback', 'Freespins'],
@@ -1294,6 +1297,90 @@ class TdsCampaign(ElasticEntity):
         return "{0}_tds_campaign.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
 
 
+class TelegramBot(ElasticEntity):
+    on_put = Signal()
+
+    _schemas = {
+        'createdon': DateTimeField,
+        'is_active': bool,
+        'token': str,
+        'domain': str,
+        'tags': list,
+        'bot_id': str,
+        'username': str,
+        'first_name': str,
+        'can_join': bool,
+        'can_read': bool,
+        'modules': list,
+    }
+        
+    @classmethod
+    def _table(cls):
+        return "{0}_telegram_bot.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
+
+
+class TelegramChat(ElasticEntity):
+    on_put = Signal()
+
+    _schemas = {
+        'createdon': DateTimeField,
+        'updatedon': DateTimeField,
+        'is_active': bool,
+        'bot_admin': str,
+        'chat_id': str,
+        'type': str,
+        'username': str,
+        'count': int,
+        'title': str,
+        'description': str,
+        'photo': str,
+        'tags': list,
+        'linked_chat': str,
+        'can_send': bool,
+        'can_invite': bool,
+        'job_remove_system_msg': bool,
+    }
+        
+    @classmethod
+    def _table(cls):
+        return "{0}_telegram_chat.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
+
+
+class TelegramMessage(ElasticEntity):
+    on_put = Signal()
+    on_pre_put = Signal()
+    on_delete = Signal()
+
+    _schemas = {
+        'createdon': DateTimeField,
+        'type': str,
+        'content': str,
+        'photo': str,
+        'tags': list,
+        'recipients': list,
+        'send_without_notify': bool,
+        'send_without_link_preview': bool,
+        'send_pin_message': bool,
+        'send_schedule': bool,
+        'scheduledon': DateTimeField,
+        'remove_schedule': bool,
+        'removedon': DateTimeField,
+
+        'status': str,
+        'publishedon': DateTimeField,
+        'chat_id': int,
+        'chat_username': str,
+        'message_id': int,
+        'sender_id': int,
+        'sender_username': str,
+        'raw': str,
+    }
+        
+    @classmethod
+    def _table(cls):
+        return "{0}_telegram_message.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
+
+
 class TdsPostback(ElasticEntity):
     on_put = Signal()
 
@@ -1321,6 +1408,59 @@ class TdsPostback(ElasticEntity):
         return "{0}_tds_postback.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
 
 
+class CasinoCommit(ElasticEntity):
+    on_put = Signal()
+
+    _schemas = {
+        'updatedon': DateTimeField,
+        'source_id': str,
+        'actor_id': str,
+        'casino': str,
+        ###
+        'title': str,
+        'website': str,
+        'languages': list,
+        'services': list,
+        'year': int,
+        'support_languages': list,
+        'support_livechat': bool,
+        'support_email': str,
+        'support_phone': str,
+        'attachs': list,
+        'logo': str,
+        'logo_small': str,
+        'licences': list,
+        'games': list,
+        'games_count': int,
+        'games_limits': list,
+        'software': list,
+        'currencies': list,
+        'default_currency': str,
+        'deposits': list,
+        'min_deposit': int,
+        'kyc_deposit': bool,
+        'withdrawal': list,
+        'min_withdrawal': int,
+        'withdrawal_monthly': int,
+        'kyc_withdrawal': bool,
+        'welcome_package_max_bonus': int,
+        'welcome_package_match': int,
+        'welcome_package_fs': int,
+        'welcome_package': str,
+        'welcome_package_note': str,
+        'welcome_package_wager': int,
+        'cashback': int,
+        'geo_whitelist': str,
+        'geo_blacklist': str,
+        'geo': list,
+        'content': str,
+    }
+        
+    @classmethod
+    def _table(cls):
+        return "{0}_casino_commit.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
+
+
 # pydantic models
 
 class UserModel(BaseModel):
@@ -1405,6 +1545,20 @@ class CasinoModel(BaseModel):
                 raise ValueError('Incorrect value')
         return v        
 
+    @validator('games_limits', pre=True, allow_reuse=True)
+    def games_limits_validator(cls, v):
+        if v:
+            if isinstance(v, list):
+                for item in v:
+                    if isinstance(item, dict):
+                        if item.get('min') and not item.get('min').isdigit():
+                            raise ValueError('Only integer values accepted')
+                        if item.get('max') and not item.get('max').isdigit():
+                            raise ValueError('Only integer values accepted')
+                return v
+            raise ValueError('Incorrect value')
+        return v        
+
     title: str = ...
     website: HttpUrl = ...
     languages: List[str] = []
@@ -1420,6 +1574,7 @@ class CasinoModel(BaseModel):
     licences: List[str] = []
     games: List[str] = []
     games_count: Optional[int]
+    games_limits: List[dict] = []
     software: List[str] = []
     currencies: conlist(str, min_items=1)
     default_currency: str
@@ -1515,53 +1670,66 @@ class ActivityFeedbackModel(BaseModel):
     cons: Optional[str]                
 
 
-class CasinoCommit(ElasticEntity):
-    on_put = Signal()
+class TelegramBotModel(BaseModel):
+    @validator('*', pre=True, allow_reuse=True)
+    def empty_str_to_none(cls, v):
+        if v == '':
+            return None
+        return v
 
-    _schemas = {
-        'updatedon': DateTimeField,
-        'source_id': str,
-        'actor_id': str,
-        'casino': str,
-        ###
-        'title': str,
-        'website': str,
-        'languages': list,
-        'services': list,
-        'year': int,
-        'support_languages': list,
-        'support_livechat': bool,
-        'support_email': str,
-        'support_phone': str,
-        'attachs': list,
-        'logo': str,
-        'logo_small': str,
-        'licences': list,
-        'games': list,
-        'games_count': int,
-        'software': list,
-        'currencies': list,
-        'default_currency': str,
-        'deposits': list,
-        'min_deposit': int,
-        'kyc_deposit': bool,
-        'withdrawal': list,
-        'min_withdrawal': int,
-        'withdrawal_monthly': int,
-        'kyc_withdrawal': bool,
-        'welcome_package_max_bonus': int,
-        'welcome_package_match': int,
-        'welcome_package_fs': int,
-        'welcome_package': str,
-        'welcome_package_note': str,
-        'welcome_package_wager': int,
-        'cashback': int,
-        'geo_whitelist': str,
-        'geo_blacklist': str,
-        'geo': list,
-        'content': str,
-    }
-        
-    @classmethod
-    def _table(cls):
-        return "{0}_casino_commit.{1}".format(os.environ.get('PROJECT', 'project'), os.environ.get('VERSION', 'v1'))
+    is_active: bool = False
+    token: str = ...
+    domain: str = ...
+    tags: Optional[List[str]] = []
+    username: Optional[str] = None
+    modules: Optional[List[str]] = []
+    can_join: bool = False
+    can_read: bool = False
+
+
+class TelegramChatModel(BaseModel):
+    @validator('*', pre=True, allow_reuse=True)
+    def empty_str_to_none(cls, v):
+        if v == '':
+            return None
+        return v
+
+    is_active: bool = False
+    bot_admin: str = ...
+    username: str = ...
+    title: str = ...
+    description: Optional[str] = None
+    photo: Optional[str] = None
+    tags: Optional[List[str]] = []
+    can_send: bool = False
+    can_invite: bool = False
+    job_remove_system_msg: bool = False
+
+
+class TelegramMessageModel(BaseModel):
+    @validator('*', pre=True, allow_reuse=True)
+    def empty_str_to_none(cls, v):
+        if v == '':
+            return None
+        return v
+
+    @validator('photo', pre=True)
+    def photo_required(cls, v, values):
+        if values['type'] == 'photo' and not v:
+            raise ValueError('Required field')
+        return v
+
+    type: str = ...
+    content: str = ...
+    photo: Optional[str] = None
+    recipients: conlist(str, min_items=1)
+    tags: Optional[List[str]] = []
+    send_without_notify: bool = False
+    send_without_link_preview: bool = False
+    send_pin_message: bool = False
+    send_schedule: bool = False
+    remove_schedule: bool = False
+    scheduledon: Optional[str] = None
+    removedon: Optional[str] = None
+    send_task: bool = False
+    status: Optional[str] = None
