@@ -2,13 +2,14 @@
 from flask import current_app
 import os
 from datetime import datetime, timedelta
-from json import dumps
+from json import dumps, loads
 import requests
 from loguru import logger 
 from notifiers import get_notifier
 import pycountry 
 from emoji import emojize
 from esentity.models import TdsCampaign, TdsHit, Page, Activity
+from esentity.telegram import telegram_api
 import time
 import ipaddress
 from celery import shared_task
@@ -239,3 +240,36 @@ def backup(indices, prefix):
                         else:
                             logger.info('Snapshot {0} status: {1}'.format(snap, item['state']))
                         break
+
+
+@shared_task
+def process_tg_message(domain, bot_id, message):
+    # delete_chat_photo
+    # group_chat_created
+    # supergroup_chat_created
+    # channel_chat_created
+
+    _data = current_app.redis.hget('tg_webhooks', f'{domain}:{bot_id}')
+    if _data:
+        _jobs = loads(_data)
+        logger.info(f'Webhook jobs found: {_jobs}')
+
+        uid = message['update_id']
+        msg = message['message']
+        mid = msg['message_id']
+        cid = msg['chat']['id']
+
+        logger.info(f'Process message, bot: {bot_id}, update_id: {uid}')
+        logger.info(f'Message body: {msg}')
+
+        if 'spectator' in _jobs['modules']:
+            job = _jobs['jobs'].get(str(cid))
+            if job:
+                logger.info(f'Job for {cid} found: {job}')
+                if job['job_remove_system_msg'] and ('new_chat_title' in msg or 'left_chat_member' in msg or 'new_chat_member' in msg or 'new_chat_photo' in msg):
+                    telegram_api(_jobs['token'], 'deleteMessage', json={'chat_id': cid, 'message_id': mid})
+                    logger.info(f"Message {mid} in {msg['chat']['title']} removed")
+            else:
+                logger.info(f'Job for {cid} not found')
+    else:
+        logger.info(f'Webhook disable or not found, bot_id: {bot_id}, domain: {domain}')
